@@ -1,6 +1,4 @@
-from openride.core.point import Point
-from openride.core.polygon import Polygon
-from openride.core.transform import Transform
+from openride import Point, Polygon, Transform
 from openride.test import get_pytest_benchmark
 from openride.test.random_core_generator import get_random
 
@@ -10,13 +8,12 @@ import numpy as np
 import pytest
 
 
-
 pytest_benchmark = get_pytest_benchmark(group="core.polygon")
 
 
 def test_init_list_points():
-    p = Polygon([Point(x) for x in range(10)]+[Point(0)])
-    assert p.vertices.shape == (11,3)
+    p = Polygon([Point(x) for x in range(10)] + [Point(0)])
+    assert p.vertices.shape == (11, 3)
 
 
 def test_post_init_connect_ends():
@@ -44,5 +41,5 @@ def test_polygon_from_shapely():
 
 @pytest_benchmark
 def test_polygon_area(benchmark):
-    poly = Polygon([Point(1,1), Point(-1,1), Point(-1,-1), Point(1,-1)])
+    poly = Polygon([Point(1, 1), Point(-1, 1), Point(-1, -1), Point(1, -1)])
     assert benchmark(poly.get_area) == 4.0
