@@ -1,10 +1,9 @@
-import openride
+from openride import Size
 import pytest
 
 
-
 def test_init():
-    s = openride.Size(1,2,3)
+    s = Size(1, 2, 3)
     assert s.x == 1
     assert s.y == 2
     assert s.z == 3
@@ -12,4 +11,4 @@ def test_init():
 
 def test_post_init_fail():
     with pytest.raises(ValueError):
-        openride.Size(-1)
\ No newline at end of file
+        Size(-1)
