@@ -6,7 +6,7 @@ from openride.core.numba.coordinate_systems import spherical_to_cartesian
 from openride.core.numba.transforms import transform_point
 from openride.viewer import vtk_utils
 from openride.viewer.camera import Camera
-from openride.viewer.interactor import Interactor
+from openride.viewer.interactor import Interactor, Event
 from openride.viewer.hud import Hud
 from openride.viewer.model_loader import ModelLoader
 from openride.viewer.models import DEFAULT_MODELS
@@ -25,6 +25,7 @@ class Viewer:
         background: Tuple[float, float, float] = (0.05, 0.05, 0.1),
         mouse_camera_interactions: bool = True,
         render_offscreen: bool = False,
+        exit_callback: callable = exit,
     ):
 
         self.renderer = vtk.vtkRenderer()
@@ -41,6 +42,7 @@ class Viewer:
 
         self.camera = Camera(self)
         self.interactor = Interactor(self, mouse_camera_interactions)
+        self.interactor.set_callback(Event.ExitEvent, exit_callback)
         self.hud = Hud(self, position=(50, 50))
 
         self._model_loader = ModelLoader()
@@ -60,6 +62,8 @@ class Viewer:
 
     def update(self, return_image: bool = False) -> Optional[np.ndarray]:
         [callback() for callback in self.callbacks]
+        if not hasattr(self, "renderWindow"):
+            return
         self.renderWindow.Render()
         self.__clear_actors()
         if return_image:
@@ -300,7 +304,7 @@ class Viewer:
             lines.append(Polyline(points))
 
         for theta in np.arange(0.0, 2 * np.pi, np.deg2rad(delta_theta)):
-            lines.append(Polyline([Point(), Point(*spherical_to_cartesian(extent, theta, np.pi / 2))]))
+            lines.append(Polyline([origin, origin + Point(*spherical_to_cartesian(extent, theta, np.pi / 2))]))
 
         self.draw_polylines(lines, color=(0.3, 0.3, 0.3), alpha=alpha, linewidth=1, persist=persist)
 
@@ -311,8 +315,10 @@ class Viewer:
         self._text_actor_index = 0
 
     def close(self):
+        self.renderWindow.Finalize()
+        self.interactor._interactor.TerminateApp()
+        del self.interactor._interactor
         del self.renderWindow
-        self.interactor._interactor.InvokeEvent("ExitEvent")
 
 
 def get_last_rendered_image(viewer: Viewer) -> np.ndarray:
